part of 'video_cubit.dart';
abstract class VideoState extends Equatable {
  @override
  List<Object> get props => [];
}

class VideoInitial extends VideoState {}
class VideoLoading extends VideoState {
  VideoLoading();

  @override
  String toString() => 'VideoLoading';
}

class VideoFailure extends VideoState {
  final String error;

  VideoFailure(this.error);

  @override
  String toString() => 'VideoFailure { error: $error }';
}

class GetListVideoSuccess extends VideoState {
  @override
  String toString() => 'GetListVideoSuccess';
}
class VideoSuccess extends VideoState {
  final String? message;

  VideoSuccess({this.message});

  @override
  String toString() => 'VideoSuccess { message: $message }';
}